@@ -18,7 +18,7 @@ class GitlabIssue:
             token=token,
             version=version
         )
-        self.issue = issue if issue else self.connection.query("issues/%s" % self.id)["data"]
+        self.issue = issue if issue else self.connection.query("issues/%s" % id)["data"]
         self.id = self.issue["id"] if self.issue else None
 
     def extract_notes(self) -> list:
